// IMediaControl.aidl
package com.cloudview.phx.music.player.control;

// Declare any non-default types here with import statements

import java.util.List;

import com.tencent.mtt.browser.music.facade.MusicInfo;

import com.cloudview.phx.music.player.control.IMediaControlCallbackAIDL;

interface IMediaControlAidl
{


	/***
	 * 初始化的时候加载数据
	 */
	void loadMusic(in List<MusicInfo> list, int position);

	/**
	 * 自动开始播放音乐
	 */
	void play(in List<MusicInfo> playlist, int position);

	/***
	 * @see MusicPlayMode
	 *
	 *      设置播放模式
	 */
	void setPlayingMode( int mode);

	/***
	 * 暂停过后恢复播放
	 */
	void start();

	/**
	 * 停止
	 */
	void stop();

	/***
	 * 暂停
	 */
	void pause();

	/***
	 * 拖动
	 */
	void seek(int position);

	/**
	 * 下一首
	 */
	void next();

	/***
	 * 上一首
	 */
	void previous();

	/***
	 * 当前是否正在播放
	 */
	boolean isPlaying();

	/**
	 * 获取当前正在播放器里面的歌曲
	 */

	MusicInfo getCurrentMusicInfo();

	/***
	 * 移除当前正在播放位置
	 */
	void removePlayListMusic(int index);

	/**
	 * 获取当前播放列表
	 */
	List<MusicInfo> getAllPlayList();

	/**
	 * 添加Music播放的回调
	 */
	void addMediaControlCallBack(in IMediaControlCallbackAIDL mediaControllerCallback);

	/**
	 * 移除 Music播放回调
	 */
	void removeMediaControlCallBack(in IMediaControlCallbackAIDL mediaControllerCallback);

	/****
	 * 更新music，主要是开始播放了过后数据库更新了，需要刷新一下id
	 */
	void updateMusicInfo(in MusicInfo info);

	/**
	 * 整个关闭播放器
	 */
	void killPlayer();

	/***
	 * 获取播放位置
	 */
	int getCurrentPosition();

	/**
	 * 播放固定位置的歌曲
	 */
	void playAtIndex(int index);

	/**
	 * 下一首播放.
	 * 等待当前歌曲播放完毕之后播放该音乐.
	 */
	void nextPlay(in MusicInfo info);

}
